pub struct Secp256k1PrivateKey(/* private fields */);secp256k1 only.Implementations
Sourceimpl Secp256k1PrivateKey
impl Secp256k1PrivateKey
pub fn new(bytes: [u8; 32]) -> Result<Self, SignatureError>
pub fn scheme(&self) -> SignatureScheme
pub fn verifying_key(&self) -> Secp256k1VerifyingKey
pub fn public_key(&self) -> Secp256k1PublicKey
pub fn generate<R>(rng: R) -> Self
Sourcepub fn from_der(bytes: &[u8]) -> Result<Self, SignatureError>
Available on crate feature pem only.
pub fn from_der(bytes: &[u8]) -> Result<Self, SignatureError>
pem only.Deserialize PKCS#8 private key from ASN.1 DER-encoded data (binary format).
Sourcepub fn to_der(&self) -> Result<Vec<u8>, SignatureError>
Available on crate feature pem only.
pub fn to_der(&self) -> Result<Vec<u8>, SignatureError>
pem only.Serialize this private key as DER-encoded PKCS#8
Sourcepub fn from_pem(s: &str) -> Result<Self, SignatureError>
Available on crate feature pem only.
pub fn from_pem(s: &str) -> Result<Self, SignatureError>
pem only.Deserialize PKCS#8-encoded private key from PEM.
Sourcepub fn to_pem(&self) -> Result<String, SignatureError>
Available on crate feature pem only.
pub fn to_pem(&self) -> Result<String, SignatureError>
pem only.Serialize this private key as PEM-encoded PKCS#8
Sourcepub fn from_suiprivkey(s: &str) -> Result<Self, SignatureError>
Available on crate feature bech32 only.
pub fn from_suiprivkey(s: &str) -> Result<Self, SignatureError>
bech32 only.Decode a Bech32 suiprivkey string produced by the Sui CLI.
Returns an error if the string does not have the suiprivkey HRP, has
an invalid Bech32 (BIP-173) checksum, has a flag byte that is not
Secp256k1, has the wrong number of key bytes, or carries bytes that do
not form a valid secp256k1 scalar.
Sourcepub fn to_suiprivkey(&self) -> Result<String, SignatureError>
Available on crate feature bech32 only.
pub fn to_suiprivkey(&self) -> Result<String, SignatureError>
bech32 only.Encode this private key as a Bech32 suiprivkey string.
Sourcepub fn from_base64(s: &str) -> Result<Self, SignatureError>
pub fn from_base64(s: &str) -> Result<Self, SignatureError>
Decode a Base64 flag || private_key string, the legacy keystore
format used for entries of the Sui CLI’s sui.keystore file.
Returns an error if the string is not valid Base64, has a flag byte that is not Secp256k1, has the wrong number of key bytes, or carries bytes that do not form a valid secp256k1 scalar.